from aiohttp import web

from singleton import Singleton
from services.basicservice import BasicService

class IssuanceCard(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cardissuance.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/v1/issuancecard/cardnumber/{cardNumber}', handler=self.issuanceCard),
                web.post('/v1/issuancecard/verify/phonenumber', handler=self.verify),
                web.post('/v1/issuancecard/create/card', handler=self.create)]

    async def issuanceCard(self, request: web.Request) -> web.Response:
        self.log.info(f"Запрос данных о карте по номеру карты: '{request.match_info['cardNumber']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/v1/issuancecard/cardnumber/<cardNumber>')

    # получение пин-кода для создания карты
    async def verify(self, request: web.Request) -> web.Response:
        phonenumber = (await request.json()).get('phonenumber')
        self.log.info(f"Проверка номера телефона: '{phonenumber}'")
        return self._createResponse(request.path, phonenumber)

    # создание карты с пин-кодом
    async def create(self, request: web.Request) -> web.Response:
        phonenumber = (await request.json()).get('phonenumber')
        self.log.info("Создание карты")
        return self._createResponse(f'{request.path}?pincode={request.query.get("pincode")}', phonenumber)


instance = IssuanceCard()
