from aiohttp import web

from singleton import Singleton
from services.basicservice import BasicService


class ElectronicPrescription(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('electronicprescription.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/connect/token', handler=self.token),
                web.get('/MedicationPrescription/$by-card', handler=self.getMedicationPrescription),
                web.post('/MedicationDispense/$register', handler=self.registerMedicationDispense),
                web.post('/MedicationDispense/$set-as-error', handler=self.cancelMedicationDispense)]

    async def token(self, request: web.Request) -> web.Response:
        self.log.info("Запрос токена")
        return self._createResponse(request.path)

    async def getMedicationPrescription(self, request: web.Request) -> web.Response:
        self.log.info("Получение электронного рецепта по карте")

        patientIdentifier = request.query.get("patientIdentifier")
        self.log.info(f'patientIdentifier {patientIdentifier}')

        methodPath = f'{request.path}?patientIdentifier={patientIdentifier}'
        if methodPath not in self.cases:
            methodPath = f'{request.path}?patientIdentifier=<patientIdentifier>'

        return self._createResponse(methodPath)

    async def registerMedicationDispense(self, request: web.Request) -> web.Response:
        self.log.info('Отпуск лекарственного средства')
        return self._createResponse(request.path)

    async def cancelMedicationDispense(self, request: web.Request) -> web.Response:
        self.log.info('Отмена отпуска лекарственного средства')
        return self._createResponse(request.path)

instance = ElectronicPrescription()
