from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class GpbSbp(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/merchant/qrc-data', handler=self.qrcData),
                web.post('/merchant/qrc-status', handler=self.qrcStatus),
                web.post('/merchant/payment/v1/cash-activate-qrc/params', handler=self.cashActivateQrc),
                web.post('/merchant/transfer/return/prepare', handler=self.refundPrepare),
                web.post('/merchant/transfer/return/confirm', handler=self.refundConfirm),
                web.post('/operation/info', handler=self.operationInfo),
                web.post('/merchant/transfer/rollback', handler=self.rollback),
                web.post('/merchant/payment/v1/cash-register-qrc', handler=self.registerStaticQr),
                web.get('/merchant/payment/v1/cash-register-qrc/{qrcId}/{paramsId}', handler=self.extendedStatus),
                web.post('/merchant/payment/v1/cash-deactivate-qrc/params', handler=self.deactivateStaticQr)]

    async def qrcData(self, request: web.Request) -> web.Response:
        self.log.info("Регистрация платежной ссылки")
        self._loadCases('cases.json')
        return self._createResponse(request.path)

    async def qrcStatus(self, request: web.Request) -> web.Response:
        self.log.info("Запрос статуса платежа")
        return self._createResponse(request.path)

    async def cashActivateQrc(self, request: web.Request) -> web.Response:
        self.log.info("Активация кассовой ссылки")
        self._loadCases('cases.json')
        return self._createResponse(request.path)

    async def refundPrepare(self, request: web.Request) -> web.Response:
        self.log.info("Создание черновика возврата")
        return self._createResponse(request.path)

    async def refundConfirm(self, request: web.Request) -> web.Response:
        self.log.info("Подтверждение возврата")
        return self._createResponse(request.path)

    async def operationInfo(self, request: web.Request) -> web.Response:
        self.log.info("Статус возврата")
        return self._createResponse(request.path)

    async def rollback(self, request: web.Request) -> web.Response:
        self.log.info("Отмена платежа")
        return self._createResponse(request.path)

    async def registerStaticQr(self, request: web.Request) -> web.Response:
        self.log.info("Регистрация кассовой ссылки")
        return self._createResponse(request.path)

    async def extendedStatus(self, request: web.Request) -> web.Response:
        self.log.info(f"Запрос расширенного статуса платежа: qrcId = {request.match_info['qrcId']}, paramsId = {request.match_info['paramsId']}")
        return self._createResponse(f"{request.path.rsplit('/', 2)[0]}/<qrcId>/<paramsId>")

    async def deactivateStaticQr(self, request: web.Request) -> web.Response:
        self.log.info("Деактивация кассовой ссылки")
        return self._createResponse(request.path)


instance = GpbSbp()
