from aiohttp import web
import xml.etree.ElementTree as ET

from services.basicservice import BasicService
from singleton import Singleton


class Manzana2019(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')
        url = "http://loyalty.manzanagroup.ru/loyalty.xsd"
        self.prefix = ".//{"+url+"}"
        ET.register_namespace("soap", "http://www.w3.org/2003/05/soap-envelope")
        ET.register_namespace("", url)

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/posprocessing.asmx', handler=self.handler)]

    async def handler(self, request: web.Request) -> web.Response:
        root = ET.fromstring(await request.text())
        action = "undefined"

        requestId = root.find(self.prefix + "RequestID").text

        if root.find(self.prefix + "BalanceRequest"):
            action = "BalanceRequest"
        checkRequest = root.find(self.prefix + "ChequeRequest")
        if checkRequest:
            opType = root.find(self.prefix + "OperationType").text
            if opType == "Sale":
                action = "ChequeRequest_" + checkRequest.get("ChequeType")
            else:
                action = "ChequeRequest_" + opType
 
        self.log.info(f"Действие: {action}")
        return self.__getResult(action, requestId)

    def __getResult(self, methodPath: str, requestId: str) -> web.Response:
        response = self._createResponse(methodPath)
        root = ET.fromstring(response.text)
        root.find(self.prefix + 'RequestID').text = requestId
        response.body = ET.tostring(root)
        self.log.info(f"Ответ : {response.text}")
        return response


instance = Manzana2019()
