from aiohttp import web
import xml.etree.ElementTree as ET

from services.basicservice import BasicService
from singleton import Singleton


class ManzanaOnline(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')
        self.prefix = ".//{http://loyalty.manzanagroup.ru/loyalty.xsd}"

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/POSProcessing.asmx', handler=self.handler)]

    async def handler(self, request: web.Request) -> web.Response:
        root = ET.fromstring(await request.text())
        action = "undefined"

        if root.find(self.prefix + "BalanceRequest"):
            action = "BalanceRequest"
        if root.find(self.prefix + "ChequeRequest"):
            action = "ChequeRequest"
            attributes = root.findall(self.prefix + "ExtendedAttribute")

            if len(attributes) > 0:
                for attribute in attributes:
                    key = attribute.find(self.prefix + "Key")
                    value = attribute.find(self.prefix + "Value")
                    if key.text == "extendedoptions" and value.text == "Markdown10":
                        action = "ChequeRequestWithMarkdown"
                        break
 
        self.log.info(f"Действие: {action}")
        response = self._createResponse(action)
        self.log.info(f"Ответ : {response.text}")
        return response

instance = ManzanaOnline()
