import base64
from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class MfgMarking(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('mfgmarking.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/mfgmarking', handler=self.handler)]

    async def handler(self, request: web.Request) -> web.Response:
        body = await request.json()

        if 'operation' not in body:
            raise web.HTTPBadRequest(text='В запросе нет поля operation')

        if 'uit' not in body:
            raise web.HTTPBadRequest(text='В запросе нет поля uit')

        uit = base64.b64decode(body['uit']).decode('utf-8')
        operation = body['operation'].lower()
        self.log.info(f"Получение статуса кода маркировки: '{uit}'")
        methodPath = f'/{operation}/<location>/{uit}'
        if methodPath not in self.cases:
            methodPath = f'/{operation}/<location>/<uit>'
        self.log.info(f"Получаем результат для: '{methodPath}'")
        return self._createResponse(methodPath)


instance = MfgMarking()
