import os
from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class SmartScales(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self.servicePath = '/smartscales'
        self._loadCases('smartscales.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post(os.path.join(self.servicePath, 'predict'), handler=self.predict),
                web.post(os.path.join(self.servicePath, 'update_prediction'), handler=self.updatePrediction),
                web.get(os.path.join(self.servicePath, 'get_status'), handler=self.getStatus)]

    async def predict(self, request: web.Request) -> web.Response:
        self.log.info('Распознание товара')
        return self._createResponse(request.path)

    async def updatePrediction(self, request: web.Request) -> web.Response:
        self.log.info('Получение информации с весов')
        return self._createResponse(request.path)

    async def getStatus(self, request: web.Request) -> web.Response:
        self.log.info('Получение статуса')
        return self._createResponse(request.path)


instance = SmartScales()
