from aiohttp import web
from services.basicservice import BasicService

from singleton import Singleton


class WebKassa(BasicService, metaclass=Singleton):
    servicePath: str

    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/api/Authorize', handler=self.getToken),
                web.post('/api/Check', handler=self.check),
                web.post('/api/MoneyOperation', handler=self.money),
                web.post('/api/ZReport', handler=self.zReport),
                web.post('/api/XReport', handler=self.xReport),
                web.post('/api/ZReport/ByShiftNumber', handler=self.zReportByShiftNumber),
                web.post('/api-history/Reports/ReportByShiftsAndSections', handler=self.reportByShiftsAndSections)]

    async def getToken(self, request: web.Request) -> web.Response:
        self.log.info("Получение токена")
        return self._createResponse(request.path)

    async def check(self, request: web.Request) -> web.Response:
        self.log.info("Регистрация чека")
        return self._createResponse(request.path)

    async def money(self, request: web.Request) -> web.Response:
        self.log.info("Внесение/изъятие наличных")
        return self._createResponse(request.path)

    async def zReport(self, request: web.Request) -> web.Response:
        self.log.info("Отчет закрытия смены")
        return self._createResponse(request.path)

    async def xReport(self, request: web.Request) -> web.Response:
        self.log.info("x-отчет")
        return self._createResponse(request.path)

    async def zReportByShiftNumber(self, request: web.Request) -> web.Response:
        self.log.info("z-отчет по номеру смены")
        return self._createResponse(request.path)

    async def reportByShiftsAndSections(self, request: web.Request) -> web.Response:
        self.log.info("z-отчет по секциям")
        return self._createResponse(request.path)


instance = WebKassa()
