from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class WinelabBonus(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.get('/api/external/v1/clients', handler=self.getClientByPhone),
                web.get('/api/external/v1/clients/cards/{cardNumber}', handler=self.getClientByCard),
                web.post('/api/v1/discounts/transactions', handler=self.calculation),
                web.post('/api/v1/discounts/transactions/{transactionId}/commit', handler=self.commit),
                web.delete('/api/v1/discounts/transactions/{transactionId}', handler=self.cancel),
                web.post('/coupon/v1/coupon/batch/use', handler=self.useCoupons),
                web.post('/api/external/v1/clients', handler=self.registerClient)]

    async def getClientByPhone(self, request: web.Request) -> web.Response:
        self.log.info('Поиск покупателя по номеру телефона')
        path = f'{request.path}?msisdn=%s'
        methodPath = path % request.query.get("msisdn")
        if not self._hasCases(methodPath):
            methodPath = path % '<phoneNumber>'
        return self._createResponse(methodPath)

    async def getClientByCard(self, request: web.Request) -> web.Response:
        self.log.info('Поиск покупателя по номеру карты')
        return self._createResponse(request.path if self._hasCases(request.path) else '/api/external/v1/clients/cards/<cardNumber>')

    async def calculation(self, request: web.Request) -> web.Response:
        subtotal = request.query.get("subtotal")
        if str(subtotal).lower() == 'true':
            self.log.info('Расчет бонусов для начисления/списания')
        else:
            self.log.info('Расчет скидок на товары')
        return self._createResponse(f'{request.path}?subtotal={subtotal}')

    async def commit(self, request: web.Request) -> web.Response:
        self.log.info('Подтверждение транзакции')
        return self._createResponse(request.path if self._hasCases(request.path) else '/api/v1/discounts/transactions/<transactionId>/commit')

    async def cancel(self, request: web.Request) -> web.Response:
        self.log.info('Отмена транзакции')
        return self._createResponse(request.path if self._hasCases(request.path) else '/api/v1/discounts/transactions/<transactionId>')

    async def useCoupons(self, request: web.Request) -> web.Response:
        self.log.info('Гашение купонов')
        return self._createResponse(request.path)

    async def registerClient(self, request: web.Request) -> web.Response:
        self.log.info('Регистрация клиента')
        return self._createResponse(request.path)


instance = WinelabBonus()
