from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class WinelabSoftCheque(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.get('/softcheques/{softChequeGuid}/shop/{shopNumber}', handler=self.getSoftCheque),
                web.get('/softcheques/shop/{shopNumber}', handler=self.getSoftCheques),
                web.patch('/softcheques/{softChequeGuid}/shop/{shopNumber}', handler=self.updateSoftChequeStatus)]

    async def getSoftCheque(self, request: web.Request) -> web.Response:
        self.log.info('Получение мягкого чека')
        return self._createResponse('/softcheques/<softChequeGuid>/shop/<shopNumber>?status=READY_TO_PAYMENT')

    async def getSoftCheques(self, request: web.Request) -> web.Response:
        self.log.info('Получение списка мягких чеков')
        return self._createResponse('/softcheques/shop/<shopNumber>?phone=<phoneNumber>&status=READY_TO_PAYMENT')

    async def updateSoftChequeStatus(self, request: web.Request) -> web.Response:
        self.log.info('Обновление статуса мягкого чека')
        return self._createResponse('/softcheques/<softChequeGuid>/shop/<shopNumber>')


instance = WinelabSoftCheque()
